@@ -2,7 +2,7 @@
 
 =head1 NAME
 
-Wrapper class around the wireguard configuration files
+WGmeta::Wrapper::Config - Class for interfacing the wireguard configs
 
 =head1 SYNOPSIS
 
@@ -42,7 +42,7 @@ bonus, the parser and encoder are exported ar usable as standalone methods
 
 =cut
 
-use v5.22;
+use v5.20.0;
 package Wireguard::WGmeta::Wrapper::Config;
 use strict;
 use warnings;
@@ -58,7 +58,7 @@ use Digest::MD5 qw(md5);
 use base 'Exporter';
 our @EXPORT = qw(read_wg_configs create_wg_config);
 
-our $VERSION = "0.0.61"; # do not change manually, this variable is updated when calling make
+our $VERSION = "0.0.0"; # do not change manually, this variable is updated when calling make
 
 use constant FALSE => 0;
 use constant TRUE => 1;
