@@ -2,7 +2,7 @@
 
 =head1 NAME
 
-Class for parsing the output of C<wg show dump>.
+WGmeta::Wrapper::Show - Class for parsing the `wg show dump` output
 
 =head1 SYNOPSIS
 
@@ -35,7 +35,7 @@ C<wg show dump> has to be captured into a string externally (e.g using L<Wiregua
 =head1 METHODS
 
 =cut
-use v5.22;
+use v5.20.0;
 package Wireguard::WGmeta::Wrapper::Show;
 use strict;
 use warnings FATAL => 'all';
@@ -44,7 +44,7 @@ use experimental 'signatures';
 use base 'Exporter';
 our @EXPORT = qw(wg_show_dump_parser);
 
-our $VERSION = "0.0.61";
+our $VERSION = "0.0.0";
 
 use constant FALSE => 0;
 use constant TRUE => 1;
